@@ -18,10 +18,10 @@ async def model_view_table(
     request: Request, model_id: Text, flash_messages: Union[List[Tuple], Tuple] = None
 ):
     if flash_messages and not isinstance(flash_messages[0], tuple):
-        request["flash"](*flash_messages)
+        request.ctx.flash(*flash_messages)
     elif flash_messages:
         for flash in flash_messages:
-            request["flash"](*flash)
+            request.ctx.flash(*flash)
     return await render_model_view(request, model_id)
 
 
@@ -60,22 +60,22 @@ async def model_edit_post(request, model_id):
         message = f'Object with id {previous_id} was updated.'
         if changes:
             message += f'Changes: from {changes["from"]} to {changes["to"]}'
-        request["flash"](message, "success")
+        request.ctx.flash(message, "success")
         log_history_event(request, message, previous_id)
     except asyncpg.exceptions.ForeignKeyViolationError as e:
-        request["flash"](
+        request.ctx.flash(
             f"ForeignKey error. "
             f"Impossible to edit field for row {previous_id}, "
             f"because exists objects that depend on it. {e}",
             "error",
         )
     except asyncpg.exceptions.UniqueViolationError:
-        request["flash"](
+        request.ctx.flash(
             f"{model_id.capitalize()} with such id already exists", "error"
         )
     except asyncpg.exceptions.NotNullViolationError as e:
         column = e.args[0].split("column")[1].split("violates")[0]
-        request["flash"](f"Field {column} cannot be null", "error")
+        request.ctx.flash(f"Field {column} cannot be null", "error")
     return await render_add_or_edit_form(
         request, model_id, new_obj_id
     )
@@ -94,7 +94,7 @@ async def model_add(request, model_id):
     request_params = {key: request.form[key][0] for key in request.form}
     not_filled = [x for x in model_data["required_columns"] if x not in request_params]
     if not_filled:
-        request["flash"](f"Fields {not_filled} required. Please fill it", "error")
+        request.ctx.flash(f"Fields {not_filled} required. Please fill it", "error")
     else:
         try:
             request_params = utils.prepare_request_params(
@@ -103,21 +103,21 @@ async def model_add(request, model_id):
             obj = await model_data["model"].create(**request_params)
             obj_id = utils.get_obj_id_from_row(model_data, request_params)
             message = f'Object with {obj_id} was added.'
-            request["flash"](message, "success")
+            request.ctx.flash(message, "success")
             log_history_event(request, message, obj_id)
         except (
             asyncpg.exceptions.StringDataRightTruncationError,
             ValueError,
             asyncpg.exceptions.ForeignKeyViolationError,
         ) as e:
-            request["flash"](e.args, "error")
+            request.ctx.flash(e.args, "error")
         except asyncpg.exceptions.UniqueViolationError:
-            request["flash"](
+            request.ctx.flash(
                 f"{model_id.capitalize()} with such id already exists", "error"
             )
         except asyncpg.exceptions.NotNullViolationError as e:
             column = e.args[0].split("column")[1].split("violates")[0]
-            request["flash"](f"Field {column} cannot be null", "error")
+            request.ctx.flash(f"Field {column} cannot be null", "error")
 
     return await render_add_or_edit_form(request, model_id)
 
